document.addEventListener('DOMContentLoaded', () => {
  const dropZone = document.getElementById('dropZone');
  const fileInput = document.getElementById('fileInput');
  const metadataPanel = document.getElementById('metadataPanel');
  const effectsPanel = document.getElementById('effectsPanel');
  const metadataContent = document.getElementById('metadataContent');
  const exportXmp = document.getElementById('exportXmp');

  // Handle drag and drop
  dropZone.addEventListener('dragover', (e) => {
    e.preventDefault();
    dropZone.style.borderColor = 'var(--accent-color)';
  });

  dropZone.addEventListener('dragleave', () => {
    dropZone.style.borderColor = 'var(--primary-color)';
  });

  dropZone.addEventListener('drop', (e) => {
    e.preventDefault();
    dropZone.style.borderColor = 'var(--primary-color)';
    handleFile(e.dataTransfer.files[0]);
  });

  // Handle click upload
  dropZone.addEventListener('click', () => {
    fileInput.click();
  });

  fileInput.addEventListener('change', (e) => {
    handleFile(e.target.files[0]);
  });

  function handleFile(file) {
    if (!file || !file.type.startsWith('image/')) {
      alert('Please upload an image file');
      return;
    }

    // Read image metadata
    const reader = new FileReader();
    reader.onload = async (e) => {
      try {
        // Extract basic image metadata
        const img = new Image();
        img.src = e.target.result;
        await img.decode();

        const metadata = {
          'File Name': file.name,
          'File Size': formatFileSize(file.size),
          'Image Width': img.naturalWidth + 'px',
          'Image Height': img.naturalHeight + 'px',
          'File Type': file.type
        };

        displayMetadata(metadata);
        metadataPanel.classList.remove('hidden');
        effectsPanel.classList.remove('hidden');
      } catch (error) {
        console.error('Error processing image:', error);
        alert('Error processing image');
      }
    };
    reader.readAsDataURL(file);
  }

  function formatFileSize(bytes) {
    if (bytes === 0) return '0 Bytes';
    const k = 1024;
    const sizes = ['Bytes', 'KB', 'MB', 'GB'];
    const i = Math.floor(Math.log(bytes) / Math.log(k));
    return parseFloat((bytes / Math.pow(k, i)).toFixed(2)) + ' ' + sizes[i];
  }

  function displayMetadata(metadata) {
    metadataContent.innerHTML = Object.entries(metadata)
      .map(([key, value]) => `<p><strong>${key}:</strong> ${value}</p>`)
      .join('');
  }

  // Handle XMP export
  exportXmp.addEventListener('click', () => {
    const xmpData = generateXmpData();
    downloadXmp(xmpData);
  });

  function generateXmpData() {
    const exposure = document.getElementById('exposure').value;
    const contrast = document.getElementById('contrast').value;
    const highlights = document.getElementById('highlights').value;
    const shadows = document.getElementById('shadows').value;

    return `<?xpacket begin="?" id="W5M0MpCehiHzreSzNTczkc9d"?>
<x:xmpmeta xmlns:x="adobe:ns:meta/">
  <rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
    <rdf:Description rdf:about=""
      xmlns:crs="http://ns.adobe.com/camera-raw-settings/1.0/">
      <crs:Exposure>${exposure}</crs:Exposure>
      <crs:Contrast>${contrast}</crs:Contrast>
      <crs:Highlights>${highlights}</crs:Highlights>
      <crs:Shadows>${shadows}</crs:Shadows>
    </rdf:Description>
  </rdf:RDF>
</x:xmpmeta>
<?xpacket end="w"?>`;
  }

  function downloadXmp(xmpContent) {
    const blob = new Blob([xmpContent], { type: 'application/xml' });
    const url = URL.createObjectURL(blob);
    const a = document.createElement('a');
    a.href = url;
    a.download = 'lightroom-effects.xmp';
    document.body.appendChild(a);
    a.click();
    document.body.removeChild(a);
    URL.revokeObjectURL(url);
  }
});
